powered by
Obtain data for one or more topics within specified populations for specified time periods and geographic scale.
All combinations of topic, population, period, and layer will be returned. Warnings will be generated for any invalid combinations.
ha_data( topic_key, population_key, period_key, layer_key, geometry = FALSE, progress = TRUE )
Data tibble containing value and standard error for each topic measure.
Character string or vector of Unique IDs(s) specifying topic(s).
Character string or vector of Unique ID(s) for population stratification(s).
Character string or vector of Unique ID(s) for time period(s).
Character string specifying an Unique ID for a geographic layer.
Attach geometry to output?
Display a progress bar?
# \donttest{ ha_set("chicagohealthatlas.org") ha_data("POP", "H", "2014-2018", "zip") # }
Run the code above in your browser using DataLab